"""This module provides constants."""

from constants.assistant_info import (
    ADDRESSBOOK_INFO_TABLE_DATA,
    ADDRESSBOOK_INFO_TABLE_HEADERS,
    NOTEBOOK_INFO_TABLE_DATA,
    NOTEBOOK_INFO_TABLE_HEADERS,
)

from constants.auto_complete_cl import COMPLETER, COMMAND_CORRECTIONS

__all__ = [
    "ADDRESSBOOK_INFO_TABLE_DATA",
    "ADDRESSBOOK_INFO_TABLE_HEADERS",
    "NOTEBOOK_INFO_TABLE_DATA",
    "NOTEBOOK_INFO_TABLE_HEADERS",
    "COMPLETER",
    "COMMAND_CORRECTIONS",
]
