from setuptools import setup, find_packages

setup(
    name='no_name_bot',
    version='1.6',
    description="Python noname bot",
    url='https://github.com/KopchukKateryna/project-S8cceS7f',
    author='Kateryna Kopchuk, Ivan Zarichnyy, Natalya Karpova, Zakhar Veremchuk, Oleg Sokolenko',
    license='MIT',
    packages=['handlers', 'helpers', 'constants','classes'],
    install_requires=[
        'autopep8==2.3.1',
        'black==24.8.0',
        'cfgv==3.4.0',
        'click==8.1.7',
        'colorlog==6.8.2',
        'distlib==0.3.8',
        'filelock==3.15.4',
        'flake8==7.1.1',
        'identify==2.6.0',
        'importlib-metadata==8.2.0',
        'mccabe==0.7.0',
        'mypy-extensions==1.0.0',
        'nodeenv==1.9.1',
        'packaging==24.1',
        'pathspec==0.12.1',
        'platformdirs==4.2.2',
        'pre-commit==3.8.0',
        'prompt-toolkit==3.0.47',
        'pycodestyle==2.12.1',
        'pyfiglet==1.0.2',
        'pyflakes==3.2.0',
        'pyreadline==2.1',
        'pyreadline3==3.4.1',
        'PyYAML==6.0.2',
        'tabulate==0.9.0',
        'tomli==2.0.1',
        'typing-extensions==4.12.2',
        'virtualenv==20.26.3',
        'wcwidth==0.2.13',
        'yapf==0.40.2',
        'zipp==3.20.0',
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'console_scripts': [
            'no_name_bot = main:main',
        ],
    },
)